@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c,v 1.130 2006/02/19 18:01:09 pborelli Exp $
+ * $Id: gedit-document.c,v 1.133 2006/08/07 18:04:06 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,7 +62,7 @@
 #define PROFILE(x)
 #endif
 
-PROFILE (static GTimer *timer = NULL);
+PROFILE (static GTimer *timer = NULL)
 
 #ifdef MAXPATHLEN
 #define GEDIT_MAX_PATH_LEN  MAXPATHLEN
@@ -94,7 +94,6 @@ struct _GeditDocumentPrivate
 	gint	     last_save_was_manually : 1; 	
 	gint	     language_set_by_user : 1;
 	gint         is_saving_as : 1;
-	gint         has_selection : 1;
 	gint         stop_cursor_moved_emission : 1;
 
 	gchar	    *uri;
@@ -138,7 +137,6 @@ enum {
 	PROP_READ_ONLY,
 	PROP_ENCODING,
 	PROP_CAN_SEARCH_AGAIN,
-	PROP_HAS_SELECTION,
 	PROP_ENABLE_SEARCH_HIGHLIGHTING
 };
 
@@ -297,11 +295,9 @@ gedit_document_get_property (GObject    *object,
 		case PROP_CAN_SEARCH_AGAIN:
 			g_value_set_boolean (value, gedit_document_get_can_search_again (doc));
 			break;
-		case PROP_HAS_SELECTION:
-			g_value_set_boolean (value, doc->priv->has_selection);
-			break;
 		case PROP_ENABLE_SEARCH_HIGHLIGHTING:
 			g_value_set_boolean (value, gedit_document_get_enable_search_highlighting (doc));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -350,22 +346,6 @@ gedit_document_mark_set (GtkTextBuffer     *buffer,
 									       iter,
 									       mark);
 
-	if (mark == gtk_text_buffer_get_insert (buffer) ||
-	    mark == gtk_text_buffer_get_selection_bound (buffer))
-	{
-		gboolean has_selection;
-
-		has_selection = gtk_text_buffer_get_selection_bounds (buffer,
-								      NULL,
-								      NULL);
-
-		if (has_selection != doc->priv->has_selection)
-		{
-			doc->priv->has_selection = has_selection;
-			g_object_notify (G_OBJECT (doc), "has-selection");
-		}
-	}
-
 	if (mark == gtk_text_buffer_get_insert (buffer))
 	{
 		emit_cursor_moved (doc);
@@ -430,16 +410,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 					 		       FALSE,
 					 		       G_PARAM_READABLE));
 
-	/* This has been properly moved in GtkTextBuffer in gtk 2.10, so when
-	 * we switch to 2.10 we can remove it and part of with gedit_document_mark_set.
-	 */
-	g_object_class_install_property (object_class, PROP_HAS_SELECTION,
-					 g_param_spec_boolean ("has-selection",
-					 		       "Has selection",
-					 		       "Wheter the document has selected text",
-					 		       FALSE,
-					 		       G_PARAM_READABLE));
-
 	g_object_class_install_property (object_class, PROP_ENABLE_SEARCH_HIGHLIGHTING,
 					 g_param_spec_boolean ("enable-search-highlighting",
 					 		       "Enable Search Highlighting",
@@ -612,7 +582,6 @@ gedit_document_init (GeditDocument *doc)
 
 	doc->priv->readonly = FALSE;
 
-	doc->priv->has_selection = FALSE;
 	doc->priv->stop_cursor_moved_emission = FALSE;
 
 	doc->priv->last_save_was_manually = TRUE;
@@ -772,9 +741,22 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 
 	if (doc->priv->uri == NULL)
 		return g_strdup_printf (_("Unsaved Document %d"),
-					doc->priv->untitled_number);	      
-	else
+					doc->priv->untitled_number);
+	else if (doc->priv->vfs_uri == NULL)
 		return gnome_vfs_format_uri_for_display (doc->priv->uri);
+	else
+	{	
+		gchar *name;
+		gchar *uri_for_display;
+		
+		name = gnome_vfs_uri_to_string (doc->priv->vfs_uri, GNOME_VFS_URI_HIDE_PASSWORD);
+		g_return_val_if_fail (name != NULL, gnome_vfs_format_uri_for_display (doc->priv->uri));
+		
+		uri_for_display = gnome_vfs_format_uri_for_display (name);
+		g_free (name);
+		
+		return uri_for_display;
+	}
 }
 
 /* move to gedit-utils? */
@@ -1199,7 +1181,7 @@ gedit_document_insert_file (GeditDocument       *doc,
 	g_return_val_if_fail (gtk_text_iter_get_buffer (iter) == 
 				GTK_TEXT_BUFFER (doc), FALSE);
 
-	// TODO
+	/* TODO */
 
 	return FALSE;
 }
@@ -1233,14 +1215,6 @@ gedit_document_get_deleted (GeditDocument *doc)
 	return !gnome_vfs_uri_exists (doc->priv->vfs_uri);
 }
 
-gboolean
-_gedit_document_get_has_selection (GeditDocument *doc)
-{
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-
-	return doc->priv->has_selection;
-}
-
 /*
  * If @line is bigger than the lines of the document, the cursor is moved
  * to the last line and FALSE is returned.
