@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-panel.c,v 1.10 2006/06/15 15:02:45 sfre Exp $
+ * $Id: gedit-panel.c,v 1.11 2006/08/09 15:17:37 pborelli Exp $
  */
 
 #include "gedit-panel.h"
@@ -416,10 +416,9 @@ gedit_panel_init (GeditPanel *panel)
 {
 	panel->priv = GEDIT_PANEL_GET_PRIVATE (panel);
 	g_return_if_fail (panel->priv != NULL);	
-	
+
 	panel->priv->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (panel->priv->tooltips));
-	gtk_object_sink (GTK_OBJECT (panel->priv->tooltips));
+	g_object_ref_sink (panel->priv->tooltips);
 }
 
 static void
