@@ -46,8 +46,8 @@
 #include "gedit-progress-message-area.h"
 #include "gedit-debug.h"
 #include "gedit-prefs-manager-app.h"
-#include "gedit-recent.h"
 #include "gedit-convert.h"
+#include "gedit-enum-types.h"
 
 #define GEDIT_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_TAB, GeditTabPrivate))
 
@@ -182,8 +182,8 @@ gedit_tab_get_property (GObject    *object,
 					     _gedit_tab_get_name (tab));
 			break;
 		case PROP_STATE:
-			g_value_set_int (value,
-					 gedit_tab_get_state (tab));
+			g_value_set_enum (value,
+					  gedit_tab_get_state (tab));
 			break;			
 		case PROP_AUTO_SAVE:
 			g_value_set_boolean (value,
@@ -265,13 +265,12 @@ gedit_tab_class_init (GeditTabClass *klass)
 							      G_PARAM_READABLE));
 	g_object_class_install_property (object_class,
 					 PROP_STATE,
-					 g_param_spec_int ("state",
-							   "State",
-							   "The tab's state",
-							   0, /* GEDIT_TAB_STATE_NORMAL */
-							   GEDIT_TAB_NUM_OF_STATES - 1,
-							   0, /* GEDIT_TAB_STATE_NORMAL */
-							   G_PARAM_READABLE));							      	
+					 g_param_spec_enum ("state",
+							    "State",
+							    "The tab's state",
+							    GEDIT_TYPE_TAB_STATE,
+							    GEDIT_TAB_STATE_NORMAL,
+							    G_PARAM_READABLE));							      	
 							      
 	g_object_class_install_property (object_class,
 					 PROP_AUTO_SAVE,
@@ -475,7 +474,7 @@ recoverable_loading_error_message_area_response (GeditMessageArea *message_area,
 						 GeditTab         *tab)
 {
 	GeditDocument *doc;
-	const gchar *uri;
+	gchar *uri;
 
 	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
@@ -507,12 +506,14 @@ recoverable_loading_error_message_area_response (GeditMessageArea *message_area,
 	}
 	else
 	{
-		gedit_recent_remove (uri);
-		
+		_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
+
 		unrecoverable_loading_error_message_area_response (message_area,
 								   response_id,
 								   tab);
 	}
+
+	g_free (uri);
 }
 
 static void 
@@ -734,7 +735,7 @@ show_saving_message_area (GeditTab *tab)
 
 		from = short_name;
 
-		to = gnome_vfs_format_uri_for_display (tab->priv->tmp_save_uri);
+		to = gedit_utils_format_uri_for_display (tab->priv->tmp_save_uri);
 
 		str = gedit_utils_str_middle_truncate (to, 
 						       MAX (20, MAX_MSG_LENGTH - len));
@@ -920,7 +921,7 @@ document_loaded (GeditDocument *document,
 			}
 			else
 			{
-				gedit_recent_remove (uri);
+				_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
 
 				if (tab->priv->state == GEDIT_TAB_STATE_LOADING_ERROR)
 				{
@@ -971,17 +972,23 @@ document_loaded (GeditDocument *document,
 							 GTK_RESPONSE_CANCEL);
 
 		gtk_widget_show (emsg);
+		g_free (uri);
 
 		return;
 	}
 	else
 	{
+		gchar *mime;
 		GList *all_documents;
 		GList *l;
 
 		g_return_if_fail (uri != NULL);
-		
-		gedit_recent_add (uri);
+
+		mime = gedit_document_get_mime_type (document);
+		_gedit_recent_add (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+				   uri,
+				   mime);
+		g_free (mime);
 
 		all_documents = gedit_app_get_documents (gedit_app_get_default ());
 
@@ -1300,8 +1307,9 @@ document_saved (GeditDocument *document,
 			else
 			{
 				/* These errors are _NOT_ recoverable */
-				gedit_recent_remove (tab->priv->tmp_save_uri);
-				
+				_gedit_recent_remove  (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+						       tab->priv->tmp_save_uri);
+
 				emsg = gedit_unrecoverable_saving_error_message_area_new (tab->priv->tmp_save_uri, 
 									  error);
 				g_return_if_fail (emsg != NULL);
@@ -1340,8 +1348,13 @@ document_saved (GeditDocument *document,
 	}
 	else
 	{
-		gedit_recent_add (tab->priv->tmp_save_uri);
-		
+		gchar *mime = gedit_document_get_mime_type (document);
+
+		_gedit_recent_add (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+				   tab->priv->tmp_save_uri,
+				   mime);
+		g_free (mime);
+
 		if (tab->priv->print_preview != NULL)
 			gedit_tab_set_state (tab, GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW);
 		else
@@ -1357,6 +1370,7 @@ gedit_tab_init (GeditTab *tab)
 {
 	GtkWidget *sw;
 	GeditDocument *doc;
+	GeditLockdownMask lockdown;
 
 	tab->priv = GEDIT_TAB_GET_PRIVATE (tab);
 
@@ -1375,7 +1389,9 @@ gedit_tab_init (GeditTab *tab)
 					GTK_POLICY_AUTOMATIC);
 
 	/* Manage auto save data */
-	tab->priv->auto_save = gedit_prefs_manager_get_auto_save ();
+	lockdown = gedit_app_get_lockdown (gedit_app_get_default ());
+	tab->priv->auto_save = gedit_prefs_manager_get_auto_save () &&
+			       !(lockdown & GEDIT_LOCKDOWN_SAVE_TO_DISK);
 	tab->priv->auto_save = (tab->priv->auto_save != FALSE);
 
 	tab->priv->auto_save_interval = gedit_prefs_manager_get_auto_save_interval ();
@@ -2259,13 +2275,19 @@ gedit_tab_set_auto_save_enabled	(GeditTab *tab,
 				 gboolean enable)
 {
 	GeditDocument *doc = NULL;
+	GeditLockdownMask lockdown;
 	
 	gedit_debug (DEBUG_TAB);
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 
-	doc = gedit_tab_get_document (tab);
+	/* Force disabling when lockdown is active */
+	lockdown = gedit_app_get_lockdown (gedit_app_get_default());
+	if (lockdown & GEDIT_LOCKDOWN_SAVE_TO_DISK)
+		enable = FALSE;
 	
+	doc = gedit_tab_get_document (tab);
+
 	if (tab->priv->auto_save == enable)
 		return;
 
