@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c,v 1.136 2006/03/19 18:38:45 chpe Exp $
+ * $Id: gedit.c,v 1.141 2006/08/07 16:42:41 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,6 @@
 #include "gedit-metadata-manager.h"
 #include "gedit-plugins-engine.h"
 #include "gedit-prefs-manager-app.h"
-#include "gedit-recent.h"
 #include "gedit-session.h"
 #include "gedit-utils.h"
 #include "gedit-window.h"
@@ -81,13 +80,13 @@ static const GOptionEntry options [] =
 	  N_("Create a new document in an existing instance of gedit"), NULL },
 
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &remaining_args,
-	  NULL, NULL }, /* collects file arguments */
+	  NULL, N_("[FILE...]") }, /* collects file arguments */
 
 	{NULL}
 };
 
 static void
-gedit_get_command_line_data (GnomeProgram *program)
+gedit_get_command_line_data (void)
 {
 	if (remaining_args)
 	{
@@ -228,8 +227,7 @@ on_message_received (const char *message,
 	g_strfreev (params);
 
 	/* body */
-	i = 1;
-	while (commands[i])
+	for (i = 1; commands[i] != NULL; i++)
 	{
 		params = g_strsplit (commands[i], "\t", -1);
 
@@ -243,7 +241,7 @@ on_message_received (const char *message,
 		}
 		else if (strcmp (params[0], "OPEN-URIS") == 0)
 		{
-			gint n_uris, i;
+			gint n_uris, j;
 			gchar **uris;
 
 			line_position = atoi (params[1]);
@@ -253,8 +251,8 @@ on_message_received (const char *message,
 			n_uris = atoi (params[3]);
 			uris = g_strsplit (params[4], " ", n_uris);
 
-			for (i = 0; i < n_uris; i++)
-				file_list = g_slist_prepend (file_list, uris[i]);
+			for (j = 0; j < n_uris; j++)
+				file_list = g_slist_prepend (file_list, uris[j]);
 			file_list = g_slist_reverse (file_list);
 
 			/* the list takes ownerhip of the strings,
@@ -267,7 +265,6 @@ on_message_received (const char *message,
 		}
 
 		g_strfreev (params);
-		++i;
 	}
 
 	g_strfreev (commands);
@@ -290,10 +287,10 @@ on_message_received (const char *message,
 
 	if (file_list != NULL)
 	{
-		gedit_cmd_load_files_from_prompt (window,
-						  file_list,
-						  encoding,
-						  line_position);
+		_gedit_cmd_load_files_from_prompt (window,
+						   file_list,
+						   encoding,
+						   line_position);
 
 		if (new_document_option)
 			gedit_window_create_tab (window, TRUE);
@@ -404,7 +401,7 @@ send_bacon_message (void)
 		command = g_string_append (command, "OPEN-URIS");
 
 		g_string_append_printf (command,
-					"\t%d\t%s\t%d\t",
+					"\t%d\t%s\t%u\t",
 					line_position,
 					encoding_charset ? encoding_charset : "",
 					g_slist_length (file_list));
@@ -449,7 +446,7 @@ main (int argc, char *argv[])
 	gedit_debug_message (DEBUG_APP, "Run gnome_program_init");
 
 	/* Setup command line options */
-	context = g_option_context_new ("[FILE...]"); /* Should be translated when out of string freeze */
+	context = g_option_context_new (_("- Edit text files"));
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	
 	/* Initialize gnome program */
@@ -473,7 +470,7 @@ main (int argc, char *argv[])
 		{
 			gedit_debug_message (DEBUG_APP, "I'm a client");
 
-			gedit_get_command_line_data (program);
+			gedit_get_command_line_data ();
 
 			send_bacon_message ();
 
@@ -500,6 +497,9 @@ main (int argc, char *argv[])
 
 	gedit_debug_message (DEBUG_APP, "Set icon");
 	
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+					   GEDIT_ICONDIR);
+
 	/* Set default icon */
 	gtk_window_set_default_icon_name ("text-editor");
 
@@ -507,9 +507,6 @@ main (int argc, char *argv[])
 	gedit_debug_message (DEBUG_APP, "Init prefs manager");
 	gedit_prefs_manager_app_init ();
 
-	gedit_debug_message (DEBUG_APP, "Init recent files");
-	gedit_recent_init ();
-
 	/* Init plugins engine */
 	gedit_debug_message (DEBUG_APP, "Init plugins");	
 	gedit_plugins_engine_init ();
@@ -528,7 +525,7 @@ main (int argc, char *argv[])
 	if (!restored)
 	{
 		gedit_debug_message (DEBUG_APP, "Analyze command line data");
-		gedit_get_command_line_data (program);
+		gedit_get_command_line_data ();
 		
 		gedit_debug_message (DEBUG_APP, "Get default app");
 		app = gedit_app_get_default ();
@@ -539,7 +536,10 @@ main (int argc, char *argv[])
 		if (file_list != NULL)
 		{
 			gedit_debug_message (DEBUG_APP, "Load files");
-			gedit_cmd_load_files_from_prompt (window, file_list, encoding, line_position);
+			_gedit_cmd_load_files_from_prompt (window, 
+							   file_list, 
+							   encoding, 
+							   line_position);
 		}
 		else
 		{
