@@ -138,7 +138,7 @@ add_node (GeditFileBookmarksStore * model, GdkPixbuf * pixbuf,
 		*iter = newiter;
 }
 
-static void
+static gboolean
 add_uri (GeditFileBookmarksStore * model, GnomeVFSURI * uri,
 	 gchar * name, guint flags, GtkTreeIter * iter)
 {
@@ -150,7 +150,7 @@ add_uri (GeditFileBookmarksStore * model, GnomeVFSURI * uri,
 	/* CHECK: how bad is this? */
 	if (!gnome_vfs_uri_exists (uri)) {
 		gnome_vfs_uri_unref (uri);
-		return;
+		return FALSE;
 	}
 
 	if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_HOME)
@@ -178,6 +178,8 @@ add_uri (GeditFileBookmarksStore * model, GnomeVFSURI * uri,
 
 	if (free_name)
 		g_free (name);
+	
+	return TRUE;
 }
 
 static void
@@ -212,11 +214,6 @@ init_special_directories (GeditFileBookmarksStore * model)
 		gnome_vfs_uri_unref (uri);
 
 	g_free (local);
-
-	/* Special dir separator */
-	add_node (model, NULL, NULL, NULL,
-		  GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR |
-		  GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR, NULL);
 }
 
 static void
@@ -243,17 +240,11 @@ check_volume_separator (GeditFileBookmarksStore * model, guint flags,
 
 static void
 add_volume (GeditFileBookmarksStore * model, GnomeVFSVolume * volume,
-	    gchar * name, guint flags, GtkTreeIter * iter)
+	    const gchar * name, guint flags, GtkTreeIter * iter)
 {
-	gboolean free_name = FALSE;
 	GdkPixbuf *pixbuf;
 	gchar *icon;
 
-	if (name == NULL) {
-		name = gnome_vfs_volume_get_display_name (volume);
-		free_name = TRUE;
-	}
-
 	icon = gnome_vfs_volume_get_icon (volume);
 	pixbuf = pixbuf_from_stock (icon);
 
@@ -262,11 +253,9 @@ add_volume (GeditFileBookmarksStore * model, GnomeVFSVolume * volume,
 
 	g_free (icon);
 
-	if (free_name)
-		g_free (name);
-
 	flags = flags & (GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE |
-			 GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT);
+			 GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT |
+			 GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_MOUNT);
 
 	if (flags)
 		check_volume_separator (model, flags, TRUE);
@@ -277,7 +266,6 @@ process_volume (GeditFileBookmarksStore * model, GnomeVFSVolume * volume,
 		gboolean * root)
 {
 	GnomeVFSVolumeType vtype;
-	gchar *uri;
 	guint flags;
 
 	vtype = gnome_vfs_volume_get_volume_type (volume);
@@ -287,15 +275,23 @@ process_volume (GeditFileBookmarksStore * model, GnomeVFSVolume * volume,
 		return FALSE;
 
 	if (gnome_vfs_volume_is_user_visible (volume)) {
+		gchar *name;
+
 		if (vtype == GNOME_VFS_VOLUME_TYPE_VFS_MOUNT)
 			flags = GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE;
 		else if (vtype == GNOME_VFS_VOLUME_TYPE_MOUNTPOINT)
 			flags = GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT;
 		else
-			flags = 0;
+			flags = GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_MOUNT;
 
-		add_volume (model, volume, NULL, flags, NULL);
+		name = gnome_vfs_volume_get_display_name (volume);
+
+		add_volume (model, volume, name, flags, NULL);
+
+		g_free (name);
 	} else if (root && !*root) {
+		gchar *uri;
+
 		uri = gnome_vfs_volume_get_activation_uri (volume);
 
 		if (strcmp (uri, "file:///") == 0) {
@@ -303,7 +299,7 @@ process_volume (GeditFileBookmarksStore * model, GnomeVFSVolume * volume,
 
 			add_volume (model, volume, "File System",
 				    GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT |
-				    GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT,
+				    GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE,
 				    NULL);
 		}
 
@@ -344,6 +340,8 @@ init_volumes (GeditFileBookmarksStore * model)
 		volume = GNOME_VFS_VOLUME (item->data);
 		process_volume (model, volume, &root);
 	}
+
+	g_list_free (volumes);
 }
 
 static void
@@ -378,7 +376,7 @@ init_bookmarks (GeditFileBookmarksStore * model)
 					uri = gnome_vfs_uri_new (unescape);
 					g_free (unescape);
 
-					add_uri (model, uri, NULL,
+					added = add_uri (model, uri, NULL,
 						 GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK,
 						 NULL);
 				} else {
@@ -389,12 +387,10 @@ init_bookmarks (GeditFileBookmarksStore * model)
 					uri = gnome_vfs_uri_new (unescape);
 					g_free (unescape);
 
-					add_uri (model, uri, pos + 1,
+					added = add_uri (model, uri, pos + 1,
 						 GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK,
 						 NULL);
 				}
-
-				added = TRUE;
 			}
 		}
 
@@ -432,9 +428,10 @@ static gint flags_order[] = {
 	GEDIT_FILE_BOOKMARKS_STORE_IS_HOME,
 	GEDIT_FILE_BOOKMARKS_STORE_IS_DESKTOP,
 	GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR,
-	GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT,
 	GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE,
+	GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT,
 	GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT,
+	GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_MOUNT,
 	GEDIT_FILE_BOOKMARKS_STORE_IS_VOLUME,
 	-1
 };
@@ -514,9 +511,9 @@ bookmarks_compare_flags (GtkTreeModel * model, GtkTreeIter * a,
 			}
 		} else if ((f1 & *flags) && (f1 & sep) != (f2 & sep)) {
 			if (f1 & sep)
-				return 1;
-			else
 				return -1;
+			else
+				return 1;
 		}
 	}
 
